=== modified file 'Makefile.am'
--- Makefile.am	2009-10-15 16:57:06 +0000
+++ Makefile.am	2009-10-15 17:17:18 +0000
@@ -20,7 +20,7 @@
   po=po
 endif
 
-TESTS= ${top_srcdir}/extra/check_include_guards.sh
+TESTS= ${top_srcdir}/extra/run_cpplint.sh
 
 SUBDIRS = ${po} \
 	  gnulib \
@@ -34,7 +34,7 @@
 EXTRA_DIST=		config/config.rpath m4/gnulib-cache.m4 \
 			config/plugin.ac config/plugin.am \
 			config/autorun.sh Doxyfile \
-			extra/check_include_guards.sh  \
+			extra/run_cpplint.sh  \
 			extra/cpplint.py \
 			extra/clean_source.sh \
 			extra/cpplint.sh

=== modified file 'extra/cpplint.py'
--- extra/cpplint.py	2009-10-15 16:57:06 +0000
+++ extra/cpplint.py	2009-10-15 17:17:18 +0000
@@ -2068,6 +2068,32 @@
 
 
 
+def CheckGlobalInclude(filename, clean_lines, linenum, include_state, error):
+  """Check rules that are applicable to #include lines.
+
+  global.h, config.h and server_includes.h should NEVER be included in headers
+  unless those headers end in _priv and therefore are private headers.
+
+  Args:
+    filename: The name of the current file.
+    clean_lines: A CleansedLines instance containing the file.
+    linenum: The number of the line to check.
+    include_state: An _IncludeState instance in which the headers are inserted.
+    error: The function to call with any errors found.
+  """
+  if not Match(r'(config|global|server_includes|_priv)\.h$', filename):
+
+    fileinfo = FileInfo(filename)
+
+    line = clean_lines.lines[linenum]
+
+    match = _RE_PATTERN_INCLUDE.search(line)
+    if match:
+      include = match.group(2)
+      if Match(r'(config|global|server_includes|_priv)\.h$', include):
+        error(filename, linenum, 'build/include_config', 4,
+              'Do not include config.h or files that include config.h in .h files')
+      
 def CheckIncludeLine(filename, clean_lines, linenum, include_state, error):
   """Check rules that are applicable to #include lines.
 
@@ -2157,6 +2183,7 @@
   match = _RE_PATTERN_INCLUDE.search(line)
   if match:
     CheckIncludeLine(filename, clean_lines, linenum, include_state, error)
+    CheckGlobalInclude(filename, clean_lines, linenum, include_state, error)
     return
 
   # Create an extended_line, which is the concatenation of the current and

=== renamed file 'extra/check_include_guards.sh' => 'extra/run_cpplint.sh'
--- extra/check_include_guards.sh	2009-10-15 16:57:06 +0000
+++ extra/run_cpplint.sh	2009-10-15 17:17:18 +0000
@@ -32,7 +32,7 @@
   fi
 fi
     
-command="python extra/cpplint.py  --filter=-whitespace,-runtime,-readability,-legal,-build,+build/header_guard"
+command="python extra/cpplint.py  --filter=-whitespace,-runtime,-readability,-legal,-build,+build/header_guard,+build/include_config"
 if test "x$1" = "x" ; then
   ${ACK} -g '.h$' | grep -v innobase | grep -v gnulib | grep -v '\.pb\.'| grep -v bak-header | grep -v '^intl' | grep -v '^config' | grep -v '\.am$' | grep -v '\.ac$' | grep -v m4 | grep -v sql_yacc.yy | grep -v '.gperf$' | grep -v 'drizzled/probes.h' | grep -v 'drizzled/function_hash.h' | grep -v 'drizzled/symbol_hash.h' | grep -v 'util/dummy.cc' | grep -v 'drizzled/sql_yacc.h' | grep -v 'drizzled/configmake.h' | xargs $command
 else
@@ -44,24 +44,6 @@
   exit ${retval}
 fi
 
-${ACK} 'global\.h' | grep -v 'check_include_guards.sh' | grep '\.h:' | grep -v _priv.h: | grep -v server_includes.h
-retval=$?
-if test ${retval} -ne 0 ; then
-  echo "ERROR: Include of global.h in non-private header."
-  exit ${retval}
-else
-  echo "Checked that global.h is not erroneously included."
-fi
-
-${ACK} 'server_includes\.h' | grep -v 'check_include_guards.sh' | grep '\.h:'
-retval=$?
-if test ${retval} -ne 0 ; then
-  echo "ERROR: Include of server_includes.h from a header file."
-  exit ${retval}
-else
-  echo "Checked that server_includes.h is not erroneously included."
-fi
-
 ${ACK} 'using namespace' | grep -v 'check_include_guards.sh' | grep '\.h:'
 retval=$?
 if test ${retval} -ne 0 ; then

